@@ -59,7 +59,7 @@ def fuckStar():
     print('\n日卫星失败，请重新尝试')
     
 def lifeGame():
-    import lifeGame
+    import f61d.lifeGame
     
 def func3():
     print('func3')
